﻿using CoreLibrary.Core;
using CoreLibrary.Joueurs;

namespace CoreLibrary.Evenements
{
    /// <summary>
    /// Classe contenant les arguments passés en paramètres lors de l'événement PartieNouveauTour.
    /// </summary>
    public class PartieNouveauTourEventArgs : EventArgs
    {
        /// <summary>
        /// Entier correspondant au nombre de tour.
        /// </summary>
        public int Tour { get; private init; }

        /// <summary>
        /// Chaîne de caractères correspondant au joueur courant.
        /// </summary>
        public string Joueur { get; private init; }

        /// <summary>
        /// Plateau du jeu en cours.
        /// </summary>
        public Plateau Plateau {  get; private init; }

        /// <summary>
        /// Code du jeu en cours.
        /// </summary>
        public Code Code { get; private init; }

        /// <summary>
        /// Constructeur de PartieNouveauTourEventArgs, avec le tour, le joueur, le plateau et le code spécifiés.
        /// </summary>
        /// <param name="tour">Le nombre de tour passé.</param>
        /// <param name="joueur">Le joueur courant.</param>
        /// <param name="plateau">Le plateau actuel de la partie.</param>
        /// <param name="code">Le dernier code ajouté.</param>
        public PartieNouveauTourEventArgs(int tour, string joueur, Plateau plateau, Code code)
        {
            Tour = tour;
            Joueur = joueur;
            Plateau = plateau;
            Code = code;
        }
    }
}
